==> egroupware_1.0.0.007-2.dfsg.orig.tar.gz: egroupware-1.0.0.007-2.dfsg/phpsysinfo/includes/lang/it.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: it.php,v 1.2 2004/01/20 20:57:47 reinerj Exp $

$text['title']          = 'Informazioni sul Sistema';

$text['vitals']         = 'Informazioni Vitali';
$text['hostname']       = 'Nome Canonico';
$text['ip']             = 'Indirizzo IP';
$text['kversion']       = 'Versione del Kernel';
$text['uptime']         = 'Tempo di Esercizio';
$text['users']          = 'Utenti Collegati';
$text['loadavg']        = 'Carico Medio';

$text['hardware']       = 'Informazioni Hardware';
$text['numcpu']         = 'Processori';
$text['cpumodel']       = 'Modello';
$text['mhz']            = 'MHz del Chip';
$text['cache']          = 'Dimensione Cache';
$text['bogomips']       = 'Bogomips del Sistema';
$text['pci']            = 'Unit PCI';
$text['ide']            = 'Unit IDE';
$text['scsi']           = 'Unit SCSI';

$text['netusage']       = 'Utilizzo della Rete';
$text['device']         = 'Device';
$text['received']       = 'Ricevuti';
$text['sent']           = 'Inviati';
$text['errors']         = 'Err/Drop';

$text['memusage']       = 'Utilizzo della Memoria';
$text['phymem']         = 'Memoria Fisica';
$text['swap']           = 'Disco di Swap';

$text['fs']             = 'Filesystem Montati';
$text['mount']          = 'Punto di Mount';
$text['partition']      = 'Partizione';

$text['percent']        = 'Uso Percentuale';
$text['type']           = 'Tipo';
$text['free']           = 'Libero';
$text['used']           = 'Usato';
$text['size']           = 'Dimensione';
$text['totals']         = 'Totali';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'none';

$text['capacity']       = 'Capacit';
  
$text['template']       = 'Template';
$text['language']       = 'Lingua';
$text['submit']         = 'Invia';
$text['created']        = 'Creato da';

$text['days']           = 'giorni';
$text['hours']          = 'ore';
$text['minutes']        = 'minuti';
?>

==> egroupware_1.2.107-2.dfsg.orig.tar.gz: egroupware-1.2.107-2.dfsg/phpsysinfo/includes/lang/it.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: it.php 21228 2006-04-06 13:52:08Z ralfbecker $

$text['title']          = 'Informazioni sul Sistema';

$text['vitals']         = 'Informazioni Vitali';
$text['hostname']       = 'Nome Canonico';
$text['ip']             = 'Indirizzo IP';
$text['kversion']       = 'Versione del Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Tempo di Esercizio';
$text['users']          = 'Utenti Collegati';
$text['loadavg']        = 'Carico Medio';

$text['hardware']       = 'Informazioni Hardware';
$text['numcpu']         = 'Processori';
$text['cpumodel']       = 'Modello';
$text['cpuspeed']       = 'MHz del Chip';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Dimensione Cache';
$text['bogomips']       = 'Bogomips del Sistema';

$text['pci']            = 'Unit PCI';
$text['ide']            = 'Unit IDE';
$text['scsi']           = 'Unit SCSI';
$text['usb']            = 'Unit USB';

$text['netusage']       = 'Utilizzo della Rete';
$text['device']         = 'Device';
$text['received']       = 'Ricevuti';
$text['sent']           = 'Inviati';
$text['errors']         = 'Err/Drop';

$text['memusage']       = 'Utilizzo della Memoria';
$text['phymem']         = 'Memoria Fisica';
$text['swap']           = 'Disco di Swap';

$text['fs']             = 'Filesystem Montati';
$text['mount']          = 'Punto di Mount';
$text['partition']      = 'Partizione';

$text['percent']        = 'Uso Percentuale';
$text['type']           = 'Tipo';
$text['free']           = 'Libero';
$text['used']           = 'Usato';
$text['size']           = 'Dimensione';
$text['totals']         = 'Totali';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'none';

$text['capacity']       = 'Capacit';
  
$text['template']       = 'Template';
$text['language']       = 'Lingua';
$text['submit']         = 'Invia';
$text['created']        = 'Creato da';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'giorni';
$text['hours']          = 'ore';
$text['minutes']        = 'minuti';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
